package temp
import "k8s.io/utils/temp"
Package temp provides an interface to handle temporary files and directories.
Index ¶
- type Dir
- func CreateTempDir(prefix string) (*Dir, error)
- func (d *Dir) Delete() error
- func (d *Dir) NewFile(name string) (io.WriteCloser, error)
- type Directory
Types ¶
type Dir ¶
type Dir struct {
// Name is the name (full path) of the created directory.
Name string
}
Dir is wrapping an temporary directory on disk.
func CreateTempDir ¶
CreateTempDir returns a new Directory wrapping a temporary directory on disk.
func (*Dir) Delete ¶
Delete the underlying directory, and all of its content.
func (*Dir) NewFile ¶
func (d *Dir) NewFile(name string) (io.WriteCloser, error)
NewFile creates a new file in the specified directory.
type Directory ¶
type Directory interface {
// NewFile creates a new file in that directory. Calling NewFile
// with the same filename twice will result in an error.
NewFile(name string) (io.WriteCloser, error)
// Delete removes the directory and its content.
Delete() error
}
Directory is an interface to a temporary directory, in which you can create new files.
Source Files ¶
dir.go doc.go
Directories ¶
| Path | Synopsis |
|---|---|
| temp/temptest | Package temptest provides utilities for testing temp files/directories testing. |
- Version
- v0.0.0-20260319190234-28399d86e0b5 (latest)
- Published
- Mar 19, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 3 hours ago –
Tools for package owners.